@@ -71,16 +71,16 @@ class EcoWittListener:
 
         if self.windchill_type == WINDCHILL_NEW:
             if (f > 50.0 or mph < 3.0):
-                return new
-            else:
                 return f
+            else:
+                return new
         if self.windchill_type == WINDCHILL_OLD:
             return old
         if self.windchill_type == WINDCHILL_HYBRID:
             if (f > 50.0 or mph < 3.0):
-                return new
-            else:
                 return old
+            else:
+                return new
         return f
 
     def convert_units(self, data):
@@ -169,6 +169,13 @@ class EcoWittListener:
             data["dewpointc"] = self.get_dew_point_c(data["tempc"],
                                                      data["humidity"])
             data["dewpointf"] = round((data["dewpointc"] * 9.0 / 5.0) + 32.0, 2)
+
+        # Soil moisture
+        for j in range(1, 10):
+            sm = f"soilmoisture{j}"
+            if sm in data:
+                data[sm] = int(data[sm])
+
         return(data)
 
     async def handler(self, request: web.BaseRequest):
